/**
 * OW2 Util
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA
*
* --------------------------------------------------------------------------
* $Id: IArchive.java 5101 2009-08-18 14:38:21Z sauthieg $
* --------------------------------------------------------------------------
*/

package org.ow2.util.archive.api;

import java.net.URL;
import java.util.Iterator;

/**
* Abstraction layer around processed archive (Jar, Directories, Bundles, ...).
* @author Guillaume Sauthier
*/
public interface IArchive {

    /**
     * @return a description of this archive. This name could be used in logger info.
     */
    String getName();

   /**
    * Returns an URL that can be used to access the resource described by this IArchive.
    * This URL MUST be canonicalized (at least when this is a file) because it is often
    * used as a key.
    * @return Returns the resource URL.
    * @throws ArchiveException if method fails.
    */
   URL getURL() throws ArchiveException;

   /**
    * @param resourceName The resource name to be looked up.
    * @return Returns the resource URL if the resource
    *         has been found. null otherwise.
    * @throws ArchiveException if method fails.
    */
   URL getResource(String resourceName) throws ArchiveException;

   /**
    * @return Returns an Iterator of Resource's URL.
    * @throws ArchiveException if method fails.
    */
   Iterator<URL> getResources() throws ArchiveException;

   /**
    * @param resourceName The resource name to be looked up.
    * @return Returns an Iterator of matching resources.
    * @throws ArchiveException if method fails.
    */
   Iterator<URL> getResources(String resourceName) throws ArchiveException;

   /**
    * @return Returns all resources name in the archive.
    * @throws ArchiveException if method fails.
    */
   Iterator<String> getEntries() throws ArchiveException;

   /**
    * Close the underlying Resource.
    * @return Returns <code>true</code> if the close was
    *         succesful, <code>false</code> otherwise.
    */
   boolean close();

   /**
    * @return the Metadata associated to this archive.
    */
   IArchiveMetadata getMetadata();

}
