/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IArchiveManager.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.archive.api;

/**
 * Interface of Archive Manager.
 * @author Francois Fornaciari
 */
public interface IArchiveManager {

    /**
     * Adds the given factory on this manager. It will look the generic info
     * used by this class to find the class object managed by this factory.
     * @param factory the factory to add.
     */
    void addFactory(final IArchiveFactory<?> factory);

    /**
     * Creates an EZBArchive implementation object for the given object.
     * @param o object to wrap into an EZBArchive.
     * @return the created archive.
     */
    IArchive getArchive(final Object o);

    /**
     * Removes the given factory on this manager. It will look the generic info
     * used by this class to find the class object managed by this factory.
     * @param factory the factory to remove.
     */
    void removeFactory(final IArchiveFactory<?> factory);
}
